{++

p d h . p a s
Copyright (c) 1997 by Alexander Staubo.

Abstract:

  Translation of pdh.h. All identifier names have been renamed to use the
  "Delphian" naming convention: eg., PDH_FMT_COUNTERVALUE has been renamed
  TPdhFmtCounterValue, HCOUNTER has been renamed HCounter etc.


Revision history:

  26-08-1997 13:43 alexs

--}

unit Pdh;

{$ALIGN ON}
{$MINENUMSIZE 4}

interface

uses
  Windows, SysUtils;

{++

Copyright (C) 1996 Microsoft Corporation

Module Name:

    PDH.H

Abstract:

    Header file for the Performance Data Helper (PDH) DLL functions.

--}

type
  TPdhStatus = Longint;

const
// version info
  PDH_CVERSION_WIN40 = $0400;
  PDH_VERSION = PDH_CVERSION_WIN40;

// data type definitions
type
  HCounter = THandle;

  HQuery = THandle;

  TPdhRawCounter =     
    record
      CStatus : DWORD;
      TimeStamp : TFileTime;
      FirstValue : LONGLONG;
      SecondValue : LONGLONG;
      MultiCount : DWORD;
    end;

  PPdhRawCounter = ^TPdhRawCounter;

  TPdhFmtCounterValue =
    record
      CStatus : DWORD;
      case Integer of
        1 :
          (
            longValue : Longint;
          );
        2 :
          (
            doubleValue : double;
          );
        3 :
          (
            largeValue : LONGLONG;
          );
    end;

  PPdhFmtCounterValue = ^TPdhFmtCounterValue;

  TPdhStatistics =
    record
      dwFormat : DWORD;
      count : DWORD;
      min : TPdhFmtCounterValue;
      max : TPdhFmtCounterValue;
      mean : TPdhFmtCounterValue;
    end;
    
  PPdhStatistics = ^TPdhStatistics;

  TPdhCOunterPathElementsA =
    record
      szMachineName : LPSTR;
      szObjectName : LPSTR;
      szInstanceName : LPSTR;
      szParentInstance : LPSTR;
      dwInstanceIndex : DWORD;
      szCounterName : LPSTR;
    end;
    
  PPdhCOunterPathElementsA = ^TPdhCOunterPathElementsA;

  TPdhCOunterPathElementsW =
    record
      szMachineName : LPWSTR;
      szObjectName : LPWSTR;
      szInstanceName : LPWSTR;
      szParentInstance : LPWSTR;
      dwInstanceIndex : DWORD;
      szCounterName : LPWSTR;
    end;

  PPdhCOunterPathElementsW = ^TPdhCOunterPathElementsW;

  TPdhCounterInfoA =
    record
      dwLength : DWORD;
      dwType : DWORD;
      CVersion : DWORD;
      CStatus : DWORD;
      lScale : Longint;
      lDefaultScale : Longint;
      dwUserData : DWORD;
      dwQueryUserData : DWORD;
      szFullPath : LPSTR;
      info : //!! This field originally had no name
        record
          case Integer of
            1 : 
              (
                CounterPath : TPdhCOunterPathElementsA;
              );
            2 :
              (
                szMachineName : LPSTR;
                szObjectName : LPSTR;
                szInstanceName : LPSTR;
                szParentInstance : LPSTR;
                dwInstanceIndex : DWORD;
                szCounterName : LPSTR;
              );
        end;
      szExplainText : LPSTR;
      DataBuffer : array[0..0] of DWORD;
    end;
    
  PPdhCounterInfoA = ^TPdhCounterInfoA;
  
  TPdhCounterInfoW =
    record
      dwLength : DWORD;
      dwType : DWORD;
      CVersion : DWORD;
      CStatus : DWORD;
      lScale : Longint;
      lDefaultScale : Longint;
      dwUserData : DWORD;
      dwQueryUserData : DWORD;
      szFullPath : LPWSTR;
      info : //!! This field originally had no name
        record
          case Integer of
            1 : 
              (
                CounterPath : TPdhCOunterPathElementsW;
              );
            2 :
              (
                szMachineName : LPWSTR;
                szObjectName : LPWSTR;
                szInstanceName : LPWSTR;
                szParentInstance : LPWSTR;
                dwInstanceIndex : DWORD;
                szCounterName : LPWSTR;
              );
        end;
      szExplainText : LPWSTR;
      DataBuffer : array[0..0] of DWORD;
    end;

  PPdhCounterInfoW = ^TPdhCounterInfoW;

// function definitions

function PdhGetDllVersion (lpdwVersion : LPDWORD) : TPdhStatus; stdcall;

//
//  Query Functions
//

function PdhOpenQuery (pReserved : Pointer; dwUserData : DWORD;
  var phQuery : HQuery) : TPdhStatus; stdcall;

function PdhAddCounterW (HQuery : HQuery; szFullCounterPath : LPCWSTR;
  dwUserData : DWORD; var phCounter : HCounter) : TPdhStatus; stdcall;

function PdhAddCounterA (HQuery : HQuery; szFullCounterPath : LPCSTR;
  dwUserData : DWORD; var phCounter : HCounter) : TPdhStatus; stdcall;

function PdhRemoveCounter (HCounter : HCounter) : TPdhStatus; stdcall;

function PdhCollectQueryData (HQuery : HQuery) : TPdhStatus; stdcall;

function PdhCloseQuery (HQuery : HQuery) : TPdhStatus; stdcall;

//
//  Counter Functions
//

function PdhGetFormattedCounterValue (HCounter : HCounter; dwFormat : DWORD;
  lpdwType : LPDWORD; pValue : PPdhFmtCounterValue) : TPdhStatus; stdcall;

// dwFormat flag values
//

const
  PDH_FMT_RAW = ($00000010);
  PDH_FMT_ANSI = ($00000020);
  PDH_FMT_UNICODE = ($00000040);
  PDH_FMT_LONG = ($00000100);
  PDH_FMT_DOUBLE = ($00000200);
  PDH_FMT_LARGE = ($00000400);
  PDH_FMT_NOSCALE = ($00001000);
  PDH_FMT_1000 = ($00002000);
  PDH_FMT_NODATA = ($00004000);

function PdhGetRawCounterValue (HCounter : HCounter; lpdwType : LPDWORD;
  pValue : PPdhRawCounter) : TPdhStatus; stdcall;

function PdhCalculateCounterFromRawValue (HCounter : HCounter;
  dwFormat : DWORD; rawValue1 : PPdhRawCounter; rawValue2 : PPdhRawCounter;
  fmtValue : PPdhFmtCounterValue) : TPdhStatus; stdcall;

function PdhComputeCounterStatistics (HCounter : HCounter; dwFormat : DWORD;
  dwFirstEntry : DWORD; dwNumEntries : DWORD;
  lpRawValueArray : PPdhRawCounter;
  data : PPdhStatistics) : TPdhStatus; stdcall;

function PdhGetCounterInfoW (HCounter : HCounter;
  bRetrieveExplainText : BOOLEAN; pdwBufferSize : LPDWORD;
  lpBuffer : PPdhCounterInfoW) : TPdhStatus; stdcall;

function PdhGetCounterInfoA (HCounter : HCounter;
  bRetrieveExplainText : BOOLEAN; pdwBufferSize : LPDWORD;
  lpBuffer : PPdhCounterInfoA) : TPdhStatus; stdcall;

const
  PDH_MAX_SCALE = 7;
  PDH_MIN_SCALE = -7;

function PdhSetCounterScaleFactor (HCounter : HCounter;
  lFactor : Longint) : TPdhStatus; stdcall;

//
//   Browsing and enumeration functions
//

function PdhConnectMachineW (szMachineName : LPCWSTR) : TPdhStatus; stdcall;

function PdhConnectMachineA (szMachineName : LPCSTR) : TPdhStatus; stdcall;

function PdhEnumMachinesW (szReserved : LPCWSTR; mszMachineList : LPWSTR;
  pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhEnumMachinesA (szReserved : LPCSTR; mszMachineList : LPSTR;
  pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhEnumObjectsW (szReserved : LPCWSTR; szMachineName : LPCWSTR;
  mszObjectList : LPWSTR; pcchBufferSize : LPDWORD; dwDetailLevel : DWORD;
  bRefresh : BOOL) : TPdhStatus; stdcall;

function PdhEnumObjectsA (szReserved : LPCSTR; szMachineName : LPCSTR;
  mszObjectList : LPSTR; pcchBufferSize : LPDWORD; dwDetailLevel : DWORD;
  bRefresh : BOOL) : TPdhStatus; stdcall;

function PdhEnumObjectItemsW (szReserved : LPCWSTR; szMachineName : LPCWSTR;
  szObjectName : LPCWSTR; mszCounterList : LPWSTR;
  pcchCounterListLength : LPDWORD; mszInstanceList : LPWSTR;
  pcchInstanceListLength : LPDWORD; dwDetailLevel : DWORD;
  dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhEnumObjectItemsA (szReserved : LPCSTR; szMachineName : LPCSTR;
  szObjectName : LPCSTR; mszCounterList : LPSTR;
  pcchCounterListLength : LPDWORD; mszInstanceList : LPSTR;
  pcchInstanceListLength : LPDWORD; dwDetailLevel : DWORD;
  dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhMakeCounterPathW (
  var pCounterPathElements : TPdhCOunterPathElementsW;
  szFullPathBuffer : LPWSTR; pcchBufferSize : LPDWORD;
  dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhMakeCounterPathA (
  var pCounterPathElements : TPdhCOunterPathElementsA;
  szFullPathBuffer : LPSTR; pcchBufferSize : LPDWORD;
  dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhParseCounterPathW (szFullPathBuffer : LPCWSTR;
  var pCounterPathElements : TPdhCOunterPathElementsW;
  pdwBufferSize : LPDWORD; dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhParseCounterPathA (szFullPathBuffer : LPCSTR;
  var pCounterPathElements : TPdhCOunterPathElementsA;
  pdwBufferSize : LPDWORD; dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhParseInstanceNameW (szInstanceString : LPCWSTR;
  szInstanceName : LPWSTR; pcchInstanceNameLength : LPDWORD;
  szParentName : LPWSTR; pcchParentNameLength : LPDWORD;
  lpIndex : LPDWORD) : TPdhStatus; stdcall;

function PdhParseInstanceNameA (szInstanceString : LPCSTR;
  szInstanceName : LPSTR; pcchInstanceNameLength : LPDWORD;
  szParentName : LPSTR; pcchParentNameLength : LPDWORD;
  lpIndex : LPDWORD) : TPdhStatus; stdcall;

function PdhValidatePathW (szFullPathBuffer : LPCWSTR) : TPdhStatus; stdcall;

function PdhValidatePathA (szFullPathBuffer : LPCSTR) : TPdhStatus; stdcall;

function PdhGetDefaultPerfObjectW (szReserved : LPCWSTR;
  szMachineName : LPCWSTR; szDefaultObjectName : LPWSTR;
  pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhGetDefaultPerfObjectA (szReserved : LPCSTR; szMachineName : LPCSTR;
  szDefaultObjectName : LPSTR; pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhGetDefaultPerfCounterW (szReserved : LPCWSTR;
  szMachineName : LPCWSTR; szObjectName : LPCWSTR;
  szDefaultCounterName : LPWSTR;
  pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhGetDefaultPerfCounterA (szReserved : LPCSTR;
  szMachineName : LPCSTR; szObjectName : LPCSTR; szDefaultCounterName : LPSTR;
  pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

type
  CounterPathCallBack = function : TPdhStatus; cdecl;

const
  {!! Added these flags: }
  PDH_CONFIGFLAG_IncludeInstanceIndex = 1;
  PDH_CONFIGFLAG_SingleCounterPerAdd = 2;
  PDH_CONFIGFLAG_SingleCounterPerDialog = 4;
  PDH_CONFIGFLAG_LocalCountersOnly = 8;
  PDH_CONFIGFLAG_WildCardInstances = 16;
  PDH_CONFIGFLAG_HideDetailBox = 32;
  PDH_CONFIGFLAG_InitializePath = 64;
  PDH_CONFIGFLAG_DisableMachineSelection = 128;
  PDH_CONFIGFLAG_Reserved = $FFFFFF00;

type
  TPdhBrowseDlgConfigW =
    record
      // Configuration flags
      bflags : DWORD; {!! This bitmask is composed of constants
        PDH_CONFIGFLAG_xxxx which had to be added to the unit }
      hWndOwner : HWND;
      szReserved : LPWSTR;
      szReturnPathBuffer : LPWSTR;
      cchReturnPathLength : DWORD;
      pCallBack : CounterPathCallBack;
      dwCallBackArg : DWORD;
      CallBackStatus : TPdhStatus;
      dwDefaultDetailLevel : DWORD;
      szDialogBoxCaption : LPWSTR;
    end;

  PPdhBrowseDlgConfigW = ^TPdhBrowseDlgConfigW;

  TPdhBrowseDlgConfigA =
    record
      // Configuration flags
      bflags : DWORD; {!! This bitmask is composed of constants
        PDH_CONFIGFLAG_xxxx which had to be added to the unit }
      hWndOwner : HWND;
      szReserved : LPSTR;
      szReturnPathBuffer : LPSTR;
      cchReturnPathLength : DWORD;
      pCallBack : CounterPathCallBack;
      dwCallBackArg : DWORD;
      CallBackStatus : TPdhStatus;
      dwDefaultDetailLevel : DWORD;
      szDialogBoxCaption : LPSTR;
    end;
    
  PPdhBrowseDlgConfigA = ^TPdhBrowseDlgConfigA;
  
function PdhBrowseCountersW (
  pBrowseDlgData : PPdhBrowseDlgConfigW) : TPdhStatus; stdcall;

function PdhBrowseCountersA (
  pBrowseDlgData : PPdhBrowseDlgConfigA) : TPdhStatus; stdcall;

function PdhExpandCounterPathW (szWildCardPath : LPCWSTR;
  mszExpandedPathList : LPWSTR;
  pcchPathListLength : LPDWORD) : TPdhStatus; stdcall;

function PdhExpandCounterPathA (szWildCardPath : LPCSTR;
  mszExpandedPathList : LPSTR;
  pcchPathListLength : LPDWORD) : TPdhStatus; stdcall;

//
//   Unicode/ANSI compatibility section
//

{$IFDEF UNICODE}

type
  PDH_COUNTER_INFO = TPdhCounterInfoW;
  PPDH_COUNTER_INFO = PPdhCounterInfoW;
  PDH_COUNTER_PATH_ELEMENTS = TPdhCOunterPathElementsW;
  PPDH_COUNTER_PATH_ELEMENTS = PPdhCOunterPathElementsW;
  PDH_BROWSE_DLG_CONFIG = TPdhBrowseDlgConfigW;
  PPDH_BROWSE_DLG_CONFIG = PPdhBrowseDlgConfigW;

function PdhAddCounter (HQuery : HQuery; szFullCounterPath : LPCWSTR;
  dwUserData : DWORD; var phCounter : HCounter) : TPdhStatus; stdcall;

function PdhGetCounterInfo (HCounter : HCounter;
  bRetrieveExplainText : BOOLEAN; pdwBufferSize : LPDWORD;
  lpBuffer : PPdhCounterInfoW) : TPdhStatus; stdcall;

function PdhConnectMachine (szMachineName : LPCWSTR) : TPdhStatus; stdcall;

function PdhEnumMachines (szReserved : LPCWSTR; mszMachineList : LPWSTR;
  pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhEnumObjects (szReserved : LPCWSTR; szMachineName : LPCWSTR;
  mszObjectList : LPWSTR; pcchBufferSize : LPDWORD; dwDetailLevel : DWORD;
  bRefresh : BOOL) : TPdhStatus; stdcall;

function PdhEnumObjectItems (szReserved : LPCWSTR; szMachineName : LPCWSTR;
  szObjectName : LPCWSTR; mszCounterList : LPWSTR;
  pcchCounterListLength : LPDWORD; mszInstanceList : LPWSTR;
  pcchInstanceListLength : LPDWORD; dwDetailLevel : DWORD;
  dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhMakeCounterPath (
  var pCounterPathElements : TPdhCOunterPathElementsW;
  szFullPathBuffer : LPWSTR; pcchBufferSize : LPDWORD;
  dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhParseCounterPath (szFullPathBuffer : LPCWSTR;
  var pCounterPathElements : TPdhCOunterPathElementsW;
  pdwBufferSize : LPDWORD; dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhParseInstanceName (szInstanceString : LPCWSTR;
  szInstanceName : LPWSTR; pcchInstanceNameLength : LPDWORD;
  szParentName : LPWSTR; pcchParentNameLength : LPDWORD;
  lpIndex : LPDWORD) : TPdhStatus; stdcall;

function PdhValidatePath (szFullPathBuffer : LPCWSTR) : TPdhStatus; stdcall;

function PdhGetDefaultPerfObject (szReserved : LPCWSTR;
  szMachineName : LPCWSTR; szDefaultObjectName : LPWSTR;
  pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhGetDefaultPerfCounter (szReserved : LPCWSTR;
  szMachineName : LPCWSTR; szObjectName : LPCWSTR;
  szDefaultCounterName : LPWSTR;
  pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhBrowseCounters (
  pBrowseDlgData : PPdhBrowseDlgConfigW) : TPdhStatus; stdcall;

function PdhExpandCounterPath (szWildCardPath : LPCWSTR;
  mszExpandedPathList : LPWSTR;
  pcchPathListLength : LPDWORD) : TPdhStatus; stdcall;

// end of UNICODE definitions

{$ELSE}

// start of ANSI definitions

type
  PDH_COUNTER_INFO = TPdhCounterInfoA;
  PPDH_COUNTER_INFO = PPdhCounterInfoA;
  PDH_COUNTER_PATH_ELEMENTS = TPdhCOunterPathElementsA;
  PPDH_COUNTER_PATH_ELEMENTS = PPdhCOunterPathElementsA;
  PDH_BROWSE_DLG_CONFIG = TPdhBrowseDlgConfigA;
  PPDH_BROWSE_DLG_CONFIG = PPdhBrowseDlgConfigA;

function PdhAddCounter (HQuery : HQuery; szFullCounterPath : LPCSTR;
  dwUserData : DWORD; var phCounter : HCounter) : TPdhStatus; stdcall;

function PdhGetCounterInfo (HCounter : HCounter;
  bRetrieveExplainText : BOOLEAN; pdwBufferSize : LPDWORD;
  lpBuffer : PPdhCounterInfoA) : TPdhStatus; stdcall;

function PdhConnectMachine (szMachineName : LPCSTR) : TPdhStatus; stdcall;

function PdhEnumMachines (szReserved : LPCSTR; mszMachineList : LPSTR;
  pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhEnumObjects (szReserved : LPCSTR; szMachineName : LPCSTR;
  mszObjectList : LPSTR; pcchBufferSize : LPDWORD; dwDetailLevel : DWORD;
  bRefresh : BOOL) : TPdhStatus; stdcall;

function PdhEnumObjectItems (szReserved : LPCSTR; szMachineName : LPCSTR;
  szObjectName : LPCSTR; mszCounterList : LPSTR;
  pcchCounterListLength : LPDWORD; mszInstanceList : LPSTR;
  pcchInstanceListLength : LPDWORD; dwDetailLevel : DWORD;
  dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhMakeCounterPath (
  var pCounterPathElements : TPdhCOunterPathElementsA;
  szFullPathBuffer : LPSTR; pcchBufferSize : LPDWORD;
  dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhParseCounterPath (szFullPathBuffer : LPCSTR;
  var pCounterPathElements : TPdhCOunterPathElementsA;
  pdwBufferSize : LPDWORD; dwFlags : DWORD) : TPdhStatus; stdcall;

function PdhParseInstanceName (szInstanceString : LPCSTR;
  szInstanceName : LPSTR; pcchInstanceNameLength : LPDWORD;
  szParentName : LPSTR; pcchParentNameLength : LPDWORD;
  lpIndex : LPDWORD) : TPdhStatus; stdcall;

function PdhValidatePath (szFullPathBuffer : LPCSTR) : TPdhStatus; stdcall;

function PdhGetDefaultPerfObject (szReserved : LPCSTR; szMachineName : LPCSTR;
  szDefaultObjectName : LPSTR; pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhGetDefaultPerfCounter (szReserved : LPCSTR;
  szMachineName : LPCSTR; szObjectName : LPCSTR; szDefaultCounterName : LPSTR;
  pcchBufferSize : LPDWORD) : TPdhStatus; stdcall;

function PdhBrowseCounters (
  pBrowseDlgData : PPdhBrowseDlgConfigA) : TPdhStatus; stdcall;

function PdhExpandCounterPath (szWildCardPath : LPCSTR;
  mszExpandedPathList : LPSTR;
  pcchPathListLength : LPDWORD) : TPdhStatus; stdcall;

// end of ANSI definitions

{$ENDIF}

{!! These functions were converted from macros }

function IsSuccessSeverity (ErrorCode : Integer) : Boolean;

function IsInformationalSeverity (ErrorCode : Integer) : Boolean;

function IsWarningSeverity (ErrorCode : Integer) : Boolean;

function IsErrorSeverity (ErrorCode : Integer) : Boolean;

implementation

const
  PdhDll = 'pdh.dll';

function PdhGetDllVersion; external PdhDll name 'PdhGetDllVersion';
function PdhOpenQuery; external PdhDll name 'PdhOpenQuery';
function PdhAddCounterW; external PdhDll name 'PdhAddCounterW';
function PdhAddCounterA; external PdhDll name 'PdhAddCounterA';
function PdhRemoveCounter; external PdhDll name 'PdhRemoveCounter';
function PdhCollectQueryData; external PdhDll name 'PdhCollectQueryData';
function PdhCloseQuery; external PdhDll name 'PdhCloseQuery';
function PdhGetFormattedCounterValue; external PdhDll
  name 'PdhGetFormattedCounterValue';
function PdhGetRawCounterValue; external PdhDll name 'PdhGetRawCounterValue';
function PdhCalculateCounterFromRawValue; external PdhDll
  name 'PdhCalculateCounterFromRawValue';
function PdhComputeCounterStatistics; external PdhDll
  name 'PdhComputeCounterStatistics';
function PdhGetCounterInfoW; external PdhDll name 'PdhGetCounterInfoW';
function PdhGetCounterInfoA; external PdhDll name 'PdhGetCounterInfoA';
function PdhSetCounterScaleFactor; external PdhDll
  name 'PdhSetCounterScaleFactor';
function PdhConnectMachineW; external PdhDll name 'PdhConnectMachineW';
function PdhConnectMachineA; external PdhDll name 'PdhConnectMachineA';
function PdhEnumMachinesW; external PdhDll name 'PdhEnumMachinesW';
function PdhEnumMachinesA; external PdhDll name 'PdhEnumMachinesA';
function PdhEnumObjectsW; external PdhDll name 'PdhEnumObjectsW';
function PdhEnumObjectsA; external PdhDll name 'PdhEnumObjectsA';
function PdhEnumObjectItemsW; external PdhDll name 'PdhEnumObjectItemsW';
function PdhEnumObjectItemsA; external PdhDll name 'PdhEnumObjectItemsA';
function PdhMakeCounterPathW; external PdhDll name 'PdhMakeCounterPathW';
function PdhMakeCounterPathA; external PdhDll name 'PdhMakeCounterPathA';
function PdhParseCounterPathW; external PdhDll name 'PdhParseCounterPathW';
function PdhParseCounterPathA; external PdhDll name 'PdhParseCounterPathA';
function PdhParseInstanceNameW; external PdhDll name 'PdhParseInstanceNameW';
function PdhParseInstanceNameA; external PdhDll name 'PdhParseInstanceNameA';
function PdhValidatePathW; external PdhDll name 'PdhValidatePathW';
function PdhValidatePathA; external PdhDll name 'PdhValidatePathA';
function PdhGetDefaultPerfObjectW; external PdhDll
  name 'PdhGetDefaultPerfObjectW';
function PdhGetDefaultPerfObjectA; external PdhDll
  name 'PdhGetDefaultPerfObjectA';
function PdhGetDefaultPerfCounterW; external PdhDll
  name 'PdhGetDefaultPerfCounterW';
function PdhGetDefaultPerfCounterA; external PdhDll
  name 'PdhGetDefaultPerfCounterA';
function PdhBrowseCountersW; external PdhDll name 'PdhBrowseCountersW';
function PdhBrowseCountersA; external PdhDll name 'PdhBrowseCountersA';
function PdhExpandCounterPathW; external PdhDll name 'PdhExpandCounterPathW';
function PdhExpandCounterPathA; external PdhDll name 'PdhExpandCounterPathA';

{$IFDEF UNICODE}

function PdhAddCounter; external PdhDll name 'PdhAddCounter';
function PdhGetCounterInfo; external PdhDll name 'PdhGetCounterInfo';
function PdhConnectMachine; external PdhDll name 'PdhConnectMachine';
function PdhEnumMachines; external PdhDll name 'PdhEnumMachines';
function PdhEnumObjects; external PdhDll name 'PdhEnumObjects';
function PdhEnumObjectItems; external PdhDll name 'PdhEnumObjectItems';
function PdhMakeCounterPath; external PdhDll name 'PdhMakeCounterPath';
function PdhParseCounterPath; external PdhDll name 'PdhParseCounterPath';
function PdhParseInstanceName; external PdhDll name 'PdhParseInstanceName';
function PdhValidatePath; external PdhDll name 'PdhValidatePath';
function PdhGetDefaultPerfObject; external PdhDll
  name 'PdhGetDefaultPerfObject';
function PdhGetDefaultPerfCounter; external PdhDll
  name 'PdhGetDefaultPerfCounter';
function PdhBrowseCounters; external PdhDll name 'PdhBrowseCounters';
function PdhExpandCounterPath; external PdhDll name 'PdhExpandCounterPath';

{$ELSE}

function PdhAddCounter; external PdhDll name 'PdhAddCounter';
function PdhGetCounterInfo; external PdhDll name 'PdhGetCounterInfo';
function PdhConnectMachine; external PdhDll name 'PdhConnectMachine';
function PdhEnumMachines; external PdhDll name 'PdhEnumMachines';
function PdhEnumObjects; external PdhDll name 'PdhEnumObjects';
function PdhEnumObjectItems; external PdhDll name 'PdhEnumObjectItems';
function PdhMakeCounterPath; external PdhDll name 'PdhMakeCounterPath';
function PdhParseCounterPath; external PdhDll name 'PdhParseCounterPath';
function PdhParseInstanceName; external PdhDll name 'PdhParseInstanceName';
function PdhValidatePath; external PdhDll name 'PdhValidatePath';
function PdhGetDefaultPerfObject; external PdhDll
  name 'PdhGetDefaultPerfObject';
function PdhGetDefaultPerfCounter; external PdhDll
  name 'PdhGetDefaultPerfCounter';
function PdhBrowseCounters; external PdhDll name 'PdhBrowseCounters';
function PdhExpandCounterPath; external PdhDll name 'PdhExpandCounterPath';

{$ENDIF}

{ Functions }

function IsSuccessSeverity (ErrorCode : Integer) : Boolean;
begin
  Result:=(ErrorCode and $C0000000) = 0;
end;

function IsInformationalSeverity (ErrorCode : Integer) : Boolean;
begin
  Result:=(ErrorCode and $C0000000) = $40000000;
end;

function IsWarningSeverity (ErrorCode : Integer) : Boolean;
begin
  Result:=(ErrorCode and $C0000000) = $80000000;
end;

function IsErrorSeverity (ErrorCode : Integer) : Boolean;
begin
  Result:=(ErrorCode and $C0000000) = $C0000000;
end;

end.

