{++

p d h . p a s
Copyright (c) 1997 by Alexander Staubo.

Abstract:

  Translation of pdh.h.

Revision history:

  26-08-1997 13:43 alexs

--}

unit Pdh;

{$ALIGN ON}
{$MINENUMSIZE 4}

interface

uses
  Windows, SysUtils;

{++

Copyright (C) 1996 Microsoft Corporation

Module Name:

    PDH.H

Abstract:

    Header file for the Performance Data Helper (PDH) DLL functions.

--}

type
  PDH_STATUS = Longint;

const
// version info
  PDH_CVERSION_WIN40 = $0400;
  PDH_VERSION = PDH_CVERSION_WIN40;

// data type definitions
type
  HCOUNTER = THandle;
  
  HQUERY = THandle;
  
  PDH_RAW_COUNTER =     
    record
      CStatus : DWORD;
      TimeStamp : TFileTime;
      FirstValue : LONGLONG;
      SecondValue : LONGLONG;
      MultiCount : DWORD;
    end;

  PPDH_RAW_COUNTER = ^PDH_RAW_COUNTER;

  PDH_FMT_COUNTERVALUE =
    record
      CStatus : DWORD;
      case Integer of
        1 :
          (
            longValue : Longint;
          );
        2 :
          (
            doubleValue : double;
          );
        3 :
          (
            largeValue : LONGLONG;
          );
    end;

  PPDH_FMT_COUNTERVALUE = ^PDH_FMT_COUNTERVALUE;

  PDH_STATISTICS =
    record
      dwFormat : DWORD;
      count : DWORD;
      min : PDH_FMT_COUNTERVALUE;
      max : PDH_FMT_COUNTERVALUE;
      mean : PDH_FMT_COUNTERVALUE;
    end;
    
  PPDH_STATISTICS = ^PDH_STATISTICS;
  
  PDH_COUNTER_PATH_ELEMENTS_A =     
    record
      szMachineName : LPSTR;
      szObjectName : LPSTR;
      szInstanceName : LPSTR;
      szParentInstance : LPSTR;
      dwInstanceIndex : DWORD;
      szCounterName : LPSTR;
    end;
    
  PPDH_COUNTER_PATH_ELEMENTS_A = ^PDH_COUNTER_PATH_ELEMENTS_A;
  
  PDH_COUNTER_PATH_ELEMENTS_W =     
    record
      szMachineName : LPWSTR;
      szObjectName : LPWSTR;
      szInstanceName : LPWSTR;
      szParentInstance : LPWSTR;
      dwInstanceIndex : DWORD;
      szCounterName : LPWSTR;
    end;
    
  PPDH_COUNTER_PATH_ELEMENTS_W = ^PDH_COUNTER_PATH_ELEMENTS_W;
  
  PDH_COUNTER_INFO_A =     
    record
      dwLength : DWORD;
      dwType : DWORD;
      CVersion : DWORD;
      CStatus : DWORD;
      lScale : Longint;
      lDefaultScale : Longint;
      dwUserData : DWORD;
      dwQueryUserData : DWORD;
      szFullPath : LPSTR;
      info : //!! This field originally had no name
        record
          case Integer of
            1 : 
              (
                CounterPath : PDH_COUNTER_PATH_ELEMENTS_A;
              );
            2 :
              (
                szMachineName : LPSTR;
                szObjectName : LPSTR;
                szInstanceName : LPSTR;
                szParentInstance : LPSTR;
                dwInstanceIndex : DWORD;
                szCounterName : LPSTR;
              );
        end;
      szExplainText : LPSTR;
      DataBuffer : array[0..0] of DWORD;
    end;
    
  PPDH_COUNTER_INFO_A = ^PDH_COUNTER_INFO_A;
  
  PDH_COUNTER_INFO_W =     
    record
      dwLength : DWORD;
      dwType : DWORD;
      CVersion : DWORD;
      CStatus : DWORD;
      lScale : Longint;
      lDefaultScale : Longint;
      dwUserData : DWORD;
      dwQueryUserData : DWORD;
      szFullPath : LPWSTR;
      info : //!! This field originally had no name
        record
          case Integer of
            1 : 
              (
                CounterPath : PDH_COUNTER_PATH_ELEMENTS_W;
              );
            2 :
              (
                szMachineName : LPWSTR;
                szObjectName : LPWSTR;
                szInstanceName : LPWSTR;
                szParentInstance : LPWSTR;
                dwInstanceIndex : DWORD;
                szCounterName : LPWSTR;
              );
        end;
      szExplainText : LPWSTR;
      DataBuffer : array[0..0] of DWORD;
    end;

  PPDH_COUNTER_INFO_W = ^PDH_COUNTER_INFO_W;

// function definitions

function PdhGetDllVersion (lpdwVersion : LPDWORD) : PDH_STATUS; stdcall;

//
//  Query Functions
//

function PdhOpenQuery (pReserved : Pointer; dwUserData : DWORD;
  var phQuery : HQUERY) : PDH_STATUS; stdcall;

function PdhAddCounterW (hQuery : HQUERY; szFullCounterPath : LPCWSTR;
  dwUserData : DWORD; var phCounter : HCOUNTER) : PDH_STATUS; stdcall;

function PdhAddCounterA (hQuery : HQUERY; szFullCounterPath : LPCSTR;
  dwUserData : DWORD; var phCounter : HCOUNTER) : PDH_STATUS; stdcall;

function PdhRemoveCounter (hCounter : HCOUNTER) : PDH_STATUS; stdcall;

function PdhCollectQueryData (hQuery : HQUERY) : PDH_STATUS; stdcall;

function PdhCloseQuery (hQuery : HQUERY) : PDH_STATUS; stdcall;

//
//  Counter Functions
//

function PdhGetFormattedCounterValue (hCounter : HCOUNTER; dwFormat : DWORD;
  lpdwType : LPDWORD; pValue : PPDH_FMT_COUNTERVALUE) : PDH_STATUS; stdcall;

// dwFormat flag values
//

const
  PDH_FMT_RAW = ($00000010);
  PDH_FMT_ANSI = ($00000020);
  PDH_FMT_UNICODE = ($00000040);
  PDH_FMT_LONG = ($00000100);
  PDH_FMT_DOUBLE = ($00000200);
  PDH_FMT_LARGE = ($00000400);
  PDH_FMT_NOSCALE = ($00001000);
  PDH_FMT_1000 = ($00002000);
  PDH_FMT_NODATA = ($00004000);

function PdhGetRawCounterValue (hCounter : HCOUNTER; lpdwType : LPDWORD;
  pValue : PPDH_RAW_COUNTER) : PDH_STATUS; stdcall;

function PdhCalculateCounterFromRawValue (hCounter : HCOUNTER;
  dwFormat : DWORD; rawValue1 : PPDH_RAW_COUNTER; rawValue2 : PPDH_RAW_COUNTER;
  fmtValue : PPDH_FMT_COUNTERVALUE) : PDH_STATUS; stdcall;

function PdhComputeCounterStatistics (hCounter : HCOUNTER; dwFormat : DWORD;
  dwFirstEntry : DWORD; dwNumEntries : DWORD;
  lpRawValueArray : PPDH_RAW_COUNTER;
  data : PPDH_STATISTICS) : PDH_STATUS; stdcall;

function PdhGetCounterInfoW (hCounter : HCOUNTER;
  bRetrieveExplainText : BOOLEAN; pdwBufferSize : LPDWORD;
  lpBuffer : PPDH_COUNTER_INFO_W) : PDH_STATUS; stdcall;

function PdhGetCounterInfoA (hCounter : HCOUNTER;
  bRetrieveExplainText : BOOLEAN; pdwBufferSize : LPDWORD;
  lpBuffer : PPDH_COUNTER_INFO_A) : PDH_STATUS; stdcall;

const
  PDH_MAX_SCALE = 7;
  PDH_MIN_SCALE = -7;

function PdhSetCounterScaleFactor (hCounter : HCOUNTER;
  lFactor : Longint) : PDH_STATUS; stdcall;

//
//   Browsing and enumeration functions
//

function PdhConnectMachineW (szMachineName : LPCWSTR) : PDH_STATUS; stdcall;

function PdhConnectMachineA (szMachineName : LPCSTR) : PDH_STATUS; stdcall;

function PdhEnumMachinesW (szReserved : LPCWSTR; mszMachineList : LPWSTR;
  pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhEnumMachinesA (szReserved : LPCSTR; mszMachineList : LPSTR;
  pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhEnumObjectsW (szReserved : LPCWSTR; szMachineName : LPCWSTR;
  mszObjectList : LPWSTR; pcchBufferSize : LPDWORD; dwDetailLevel : DWORD;
  bRefresh : BOOL) : PDH_STATUS; stdcall;

function PdhEnumObjectsA (szReserved : LPCSTR; szMachineName : LPCSTR;
  mszObjectList : LPSTR; pcchBufferSize : LPDWORD; dwDetailLevel : DWORD;
  bRefresh : BOOL) : PDH_STATUS; stdcall;

function PdhEnumObjectItemsW (szReserved : LPCWSTR; szMachineName : LPCWSTR;
  szObjectName : LPCWSTR; mszCounterList : LPWSTR;
  pcchCounterListLength : LPDWORD; mszInstanceList : LPWSTR;
  pcchInstanceListLength : LPDWORD; dwDetailLevel : DWORD;
  dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhEnumObjectItemsA (szReserved : LPCSTR; szMachineName : LPCSTR;
  szObjectName : LPCSTR; mszCounterList : LPSTR;
  pcchCounterListLength : LPDWORD; mszInstanceList : LPSTR;
  pcchInstanceListLength : LPDWORD; dwDetailLevel : DWORD;
  dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhMakeCounterPathW (
  var pCounterPathElements : PDH_COUNTER_PATH_ELEMENTS_W;
  szFullPathBuffer : LPWSTR; pcchBufferSize : LPDWORD;
  dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhMakeCounterPathA (
  var pCounterPathElements : PDH_COUNTER_PATH_ELEMENTS_A;
  szFullPathBuffer : LPSTR; pcchBufferSize : LPDWORD;
  dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhParseCounterPathW (szFullPathBuffer : LPCWSTR;
  var pCounterPathElements : PDH_COUNTER_PATH_ELEMENTS_W;
  pdwBufferSize : LPDWORD; dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhParseCounterPathA (szFullPathBuffer : LPCSTR;
  var pCounterPathElements : PDH_COUNTER_PATH_ELEMENTS_A;
  pdwBufferSize : LPDWORD; dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhParseInstanceNameW (szInstanceString : LPCWSTR;
  szInstanceName : LPWSTR; pcchInstanceNameLength : LPDWORD;
  szParentName : LPWSTR; pcchParentNameLength : LPDWORD;
  lpIndex : LPDWORD) : PDH_STATUS; stdcall;

function PdhParseInstanceNameA (szInstanceString : LPCSTR;
  szInstanceName : LPSTR; pcchInstanceNameLength : LPDWORD;
  szParentName : LPSTR; pcchParentNameLength : LPDWORD;
  lpIndex : LPDWORD) : PDH_STATUS; stdcall;

function PdhValidatePathW (szFullPathBuffer : LPCWSTR) : PDH_STATUS; stdcall;

function PdhValidatePathA (szFullPathBuffer : LPCSTR) : PDH_STATUS; stdcall;

function PdhGetDefaultPerfObjectW (szReserved : LPCWSTR;
  szMachineName : LPCWSTR; szDefaultObjectName : LPWSTR;
  pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhGetDefaultPerfObjectA (szReserved : LPCSTR; szMachineName : LPCSTR;
  szDefaultObjectName : LPSTR; pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhGetDefaultPerfCounterW (szReserved : LPCWSTR;
  szMachineName : LPCWSTR; szObjectName : LPCWSTR;
  szDefaultCounterName : LPWSTR;
  pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhGetDefaultPerfCounterA (szReserved : LPCSTR;
  szMachineName : LPCSTR; szObjectName : LPCSTR; szDefaultCounterName : LPSTR;
  pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

type
  TCounterPathCallback = function : PDH_STATUS; cdecl;

const
  {!! Added these flags: }
  PDH_CONFIGFLAG_IncludeInstanceIndex = 1;
  PDH_CONFIGFLAG_SingleCounterPerAdd = 2;
  PDH_CONFIGFLAG_SingleCounterPerDialog = 4;
  PDH_CONFIGFLAG_LocalCountersOnly = 8;
  PDH_CONFIGFLAG_WildCardInstances = 16;
  PDH_CONFIGFLAG_HideDetailBox = 32;
  PDH_CONFIGFLAG_InitializePath = 64;
  PDH_CONFIGFLAG_DisableMachineSelection = 128;
  PDH_CONFIGFLAG_Reserved = $FFFFFF00;

type
  PDH_BROWSE_DLG_CONFIG_W =
    record
      // Configuration flags
      bflags : DWORD; {!! This bitmask is composed of constants
        PDH_CONFIGFLAG_xxxx which had to be added to the unit }
      hWndOwner : HWND;
      szReserved : LPWSTR;
      szReturnPathBuffer : LPWSTR;
      cchReturnPathLength : DWORD;
      pCallBack : TCounterPathCallback;
      dwCallBackArg : DWORD;
      CallBackStatus : PDH_STATUS;
      dwDefaultDetailLevel : DWORD;
      szDialogBoxCaption : LPWSTR;
    end;

  PPDH_BROWSE_DLG_CONFIG_W = ^PDH_BROWSE_DLG_CONFIG_W;

  PDH_BROWSE_DLG_CONFIG_A =
    record
      // Configuration flags
      bflags : DWORD; {!! This bitmask is composed of constants
        PDH_CONFIGFLAG_xxxx which had to be added to the unit }
      hWndOwner : HWND;
      szReserved : LPSTR;
      szReturnPathBuffer : LPSTR;
      cchReturnPathLength : DWORD;
      pCallBack : TCounterPathCallback;
      dwCallBackArg : DWORD;
      CallBackStatus : PDH_STATUS;
      dwDefaultDetailLevel : DWORD;
      szDialogBoxCaption : LPSTR;
    end;
    
  PPDH_BROWSE_DLG_CONFIG_A = ^PDH_BROWSE_DLG_CONFIG_A;
  
function PdhBrowseCountersW (
  pBrowseDlgData : PPDH_BROWSE_DLG_CONFIG_W) : PDH_STATUS; stdcall;

function PdhBrowseCountersA (
  pBrowseDlgData : PPDH_BROWSE_DLG_CONFIG_A) : PDH_STATUS; stdcall;

function PdhExpandCounterPathW (szWildCardPath : LPCWSTR;
  mszExpandedPathList : LPWSTR;
  pcchPathListLength : LPDWORD) : PDH_STATUS; stdcall;

function PdhExpandCounterPathA (szWildCardPath : LPCSTR;
  mszExpandedPathList : LPSTR;
  pcchPathListLength : LPDWORD) : PDH_STATUS; stdcall;

//
//   Unicode/ANSI compatibility section
//

{$IFDEF UNICODE}

type
  PDH_COUNTER_INFO = PDH_COUNTER_INFO_W;
  PPDH_COUNTER_INFO = PPDH_COUNTER_INFO_W;
  PDH_COUNTER_PATH_ELEMENTS = PDH_COUNTER_PATH_ELEMENTS_W;
  PPDH_COUNTER_PATH_ELEMENTS = PPDH_COUNTER_PATH_ELEMENTS_W;
  PDH_BROWSE_DLG_CONFIG = PDH_BROWSE_DLG_CONFIG_W;
  PPDH_BROWSE_DLG_CONFIG = PPDH_BROWSE_DLG_CONFIG_W;

function PdhAddCounter (hQuery : HQUERY; szFullCounterPath : LPCWSTR;
  dwUserData : DWORD; var phCounter : HCOUNTER) : PDH_STATUS; stdcall;

function PdhGetCounterInfo (hCounter : HCOUNTER;
  bRetrieveExplainText : BOOLEAN; pdwBufferSize : LPDWORD;
  lpBuffer : PPDH_COUNTER_INFO_W) : PDH_STATUS; stdcall;

function PdhConnectMachine (szMachineName : LPCWSTR) : PDH_STATUS; stdcall;

function PdhEnumMachines (szReserved : LPCWSTR; mszMachineList : LPWSTR;
  pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhEnumObjects (szReserved : LPCWSTR; szMachineName : LPCWSTR;
  mszObjectList : LPWSTR; pcchBufferSize : LPDWORD; dwDetailLevel : DWORD;
  bRefresh : BOOL) : PDH_STATUS; stdcall;

function PdhEnumObjectItems (szReserved : LPCWSTR; szMachineName : LPCWSTR;
  szObjectName : LPCWSTR; mszCounterList : LPWSTR;
  pcchCounterListLength : LPDWORD; mszInstanceList : LPWSTR;
  pcchInstanceListLength : LPDWORD; dwDetailLevel : DWORD;
  dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhMakeCounterPath (
  var pCounterPathElements : PDH_COUNTER_PATH_ELEMENTS_W;
  szFullPathBuffer : LPWSTR; pcchBufferSize : LPDWORD;
  dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhParseCounterPath (szFullPathBuffer : LPCWSTR;
  var pCounterPathElements : PDH_COUNTER_PATH_ELEMENTS_W;
  pdwBufferSize : LPDWORD; dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhParseInstanceName (szInstanceString : LPCWSTR;
  szInstanceName : LPWSTR; pcchInstanceNameLength : LPDWORD;
  szParentName : LPWSTR; pcchParentNameLength : LPDWORD;
  lpIndex : LPDWORD) : PDH_STATUS; stdcall;

function PdhValidatePath (szFullPathBuffer : LPCWSTR) : PDH_STATUS; stdcall;

function PdhGetDefaultPerfObject (szReserved : LPCWSTR;
  szMachineName : LPCWSTR; szDefaultObjectName : LPWSTR;
  pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhGetDefaultPerfCounter (szReserved : LPCWSTR;
  szMachineName : LPCWSTR; szObjectName : LPCWSTR;
  szDefaultCounterName : LPWSTR;
  pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhBrowseCounters (
  pBrowseDlgData : PPDH_BROWSE_DLG_CONFIG_W) : PDH_STATUS; stdcall;

function PdhExpandCounterPath (szWildCardPath : LPCWSTR;
  mszExpandedPathList : LPWSTR;
  pcchPathListLength : LPDWORD) : PDH_STATUS; stdcall;

// end of UNICODE definitions

{$ELSE}

// start of ANSI definitions

type
  PDH_COUNTER_INFO = PDH_COUNTER_INFO_A;
  PPDH_COUNTER_INFO = PPDH_COUNTER_INFO_A;
  PDH_COUNTER_PATH_ELEMENTS = PDH_COUNTER_PATH_ELEMENTS_A;
  PPDH_COUNTER_PATH_ELEMENTS = PPDH_COUNTER_PATH_ELEMENTS_A;
  PDH_BROWSE_DLG_CONFIG = PDH_BROWSE_DLG_CONFIG_A;
  PPDH_BROWSE_DLG_CONFIG = PPDH_BROWSE_DLG_CONFIG_A;

function PdhAddCounter (hQuery : HQUERY; szFullCounterPath : LPCSTR;
  dwUserData : DWORD; var phCounter : HCOUNTER) : PDH_STATUS; stdcall;

function PdhGetCounterInfo (hCounter : HCOUNTER;
  bRetrieveExplainText : BOOLEAN; pdwBufferSize : LPDWORD;
  lpBuffer : PPDH_COUNTER_INFO_A) : PDH_STATUS; stdcall;

function PdhConnectMachine (szMachineName : LPCSTR) : PDH_STATUS; stdcall;

function PdhEnumMachines (szReserved : LPCSTR; mszMachineList : LPSTR;
  pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhEnumObjects (szReserved : LPCSTR; szMachineName : LPCSTR;
  mszObjectList : LPSTR; pcchBufferSize : LPDWORD; dwDetailLevel : DWORD;
  bRefresh : BOOL) : PDH_STATUS; stdcall;

function PdhEnumObjectItems (szReserved : LPCSTR; szMachineName : LPCSTR;
  szObjectName : LPCSTR; mszCounterList : LPSTR;
  pcchCounterListLength : LPDWORD; mszInstanceList : LPSTR;
  pcchInstanceListLength : LPDWORD; dwDetailLevel : DWORD;
  dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhMakeCounterPath (
  var pCounterPathElements : PDH_COUNTER_PATH_ELEMENTS_A;
  szFullPathBuffer : LPSTR; pcchBufferSize : LPDWORD;
  dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhParseCounterPath (szFullPathBuffer : LPCSTR;
  var pCounterPathElements : PDH_COUNTER_PATH_ELEMENTS_A;
  pdwBufferSize : LPDWORD; dwFlags : DWORD) : PDH_STATUS; stdcall;

function PdhParseInstanceName (szInstanceString : LPCSTR;
  szInstanceName : LPSTR; pcchInstanceNameLength : LPDWORD;
  szParentName : LPSTR; pcchParentNameLength : LPDWORD;
  lpIndex : LPDWORD) : PDH_STATUS; stdcall;

function PdhValidatePath (szFullPathBuffer : LPCSTR) : PDH_STATUS; stdcall;

function PdhGetDefaultPerfObject (szReserved : LPCSTR; szMachineName : LPCSTR;
  szDefaultObjectName : LPSTR; pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhGetDefaultPerfCounter (szReserved : LPCSTR;
  szMachineName : LPCSTR; szObjectName : LPCSTR; szDefaultCounterName : LPSTR;
  pcchBufferSize : LPDWORD) : PDH_STATUS; stdcall;

function PdhBrowseCounters (
  pBrowseDlgData : PPDH_BROWSE_DLG_CONFIG_A) : PDH_STATUS; stdcall;

function PdhExpandCounterPath (szWildCardPath : LPCSTR;
  mszExpandedPathList : LPSTR;
  pcchPathListLength : LPDWORD) : PDH_STATUS; stdcall;

// end of ANSI definitions

{$ENDIF}

{!! These functions were converted from macros }

function IsSuccessSeverity (ErrorCode : Integer) : Boolean;

function IsInformationalSeverity (ErrorCode : Integer) : Boolean;

function IsWarningSeverity (ErrorCode : Integer) : Boolean;

function IsErrorSeverity (ErrorCode : Integer) : Boolean;

implementation

const
  PdhDll = 'pdh.dll'; {!! htrans: DLL name could not be determined }

{!! htrans: DLL imports }

function PdhGetDllVersion; external PdhDll name 'PdhGetDllVersion';
function PdhOpenQuery; external PdhDll name 'PdhOpenQuery';
function PdhAddCounterW; external PdhDll name 'PdhAddCounterW';
function PdhAddCounterA; external PdhDll name 'PdhAddCounterA';
function PdhRemoveCounter; external PdhDll name 'PdhRemoveCounter';
function PdhCollectQueryData; external PdhDll name 'PdhCollectQueryData';
function PdhCloseQuery; external PdhDll name 'PdhCloseQuery';
function PdhGetFormattedCounterValue; external PdhDll
  name 'PdhGetFormattedCounterValue';
function PdhGetRawCounterValue; external PdhDll name 'PdhGetRawCounterValue';
function PdhCalculateCounterFromRawValue; external PdhDll
  name 'PdhCalculateCounterFromRawValue';
function PdhComputeCounterStatistics; external PdhDll
  name 'PdhComputeCounterStatistics';
function PdhGetCounterInfoW; external PdhDll name 'PdhGetCounterInfoW';
function PdhGetCounterInfoA; external PdhDll name 'PdhGetCounterInfoA';
function PdhSetCounterScaleFactor; external PdhDll
  name 'PdhSetCounterScaleFactor';
function PdhConnectMachineW; external PdhDll name 'PdhConnectMachineW';
function PdhConnectMachineA; external PdhDll name 'PdhConnectMachineA';
function PdhEnumMachinesW; external PdhDll name 'PdhEnumMachinesW';
function PdhEnumMachinesA; external PdhDll name 'PdhEnumMachinesA';
function PdhEnumObjectsW; external PdhDll name 'PdhEnumObjectsW';
function PdhEnumObjectsA; external PdhDll name 'PdhEnumObjectsA';
function PdhEnumObjectItemsW; external PdhDll name 'PdhEnumObjectItemsW';
function PdhEnumObjectItemsA; external PdhDll name 'PdhEnumObjectItemsA';
function PdhMakeCounterPathW; external PdhDll name 'PdhMakeCounterPathW';
function PdhMakeCounterPathA; external PdhDll name 'PdhMakeCounterPathA';
function PdhParseCounterPathW; external PdhDll name 'PdhParseCounterPathW';
function PdhParseCounterPathA; external PdhDll name 'PdhParseCounterPathA';
function PdhParseInstanceNameW; external PdhDll name 'PdhParseInstanceNameW';
function PdhParseInstanceNameA; external PdhDll name 'PdhParseInstanceNameA';
function PdhValidatePathW; external PdhDll name 'PdhValidatePathW';
function PdhValidatePathA; external PdhDll name 'PdhValidatePathA';
function PdhGetDefaultPerfObjectW; external PdhDll
  name 'PdhGetDefaultPerfObjectW';
function PdhGetDefaultPerfObjectA; external PdhDll
  name 'PdhGetDefaultPerfObjectA';
function PdhGetDefaultPerfCounterW; external PdhDll
  name 'PdhGetDefaultPerfCounterW';
function PdhGetDefaultPerfCounterA; external PdhDll
  name 'PdhGetDefaultPerfCounterA';
function PdhBrowseCountersW; external PdhDll name 'PdhBrowseCountersW';
function PdhBrowseCountersA; external PdhDll name 'PdhBrowseCountersA';
function PdhExpandCounterPathW; external PdhDll name 'PdhExpandCounterPathW';
function PdhExpandCounterPathA; external PdhDll name 'PdhExpandCounterPathA';

{$IFDEF UNICODE}

function PdhAddCounter; external PdhDll name 'PdhAddCounter';
function PdhGetCounterInfo; external PdhDll name 'PdhGetCounterInfo';
function PdhConnectMachine; external PdhDll name 'PdhConnectMachine';
function PdhEnumMachines; external PdhDll name 'PdhEnumMachines';
function PdhEnumObjects; external PdhDll name 'PdhEnumObjects';
function PdhEnumObjectItems; external PdhDll name 'PdhEnumObjectItems';
function PdhMakeCounterPath; external PdhDll name 'PdhMakeCounterPath';
function PdhParseCounterPath; external PdhDll name 'PdhParseCounterPath';
function PdhParseInstanceName; external PdhDll name 'PdhParseInstanceName';
function PdhValidatePath; external PdhDll name 'PdhValidatePath';
function PdhGetDefaultPerfObject; external PdhDll
  name 'PdhGetDefaultPerfObject';
function PdhGetDefaultPerfCounter; external PdhDll
  name 'PdhGetDefaultPerfCounter';
function PdhBrowseCounters; external PdhDll name 'PdhBrowseCounters';
function PdhExpandCounterPath; external PdhDll name 'PdhExpandCounterPath';

{$ELSE}

function PdhAddCounter; external PdhDll name 'PdhAddCounter';
function PdhGetCounterInfo; external PdhDll name 'PdhGetCounterInfo';
function PdhConnectMachine; external PdhDll name 'PdhConnectMachine';
function PdhEnumMachines; external PdhDll name 'PdhEnumMachines';
function PdhEnumObjects; external PdhDll name 'PdhEnumObjects';
function PdhEnumObjectItems; external PdhDll name 'PdhEnumObjectItems';
function PdhMakeCounterPath; external PdhDll name 'PdhMakeCounterPath';
function PdhParseCounterPath; external PdhDll name 'PdhParseCounterPath';
function PdhParseInstanceName; external PdhDll name 'PdhParseInstanceName';
function PdhValidatePath; external PdhDll name 'PdhValidatePath';
function PdhGetDefaultPerfObject; external PdhDll
  name 'PdhGetDefaultPerfObject';
function PdhGetDefaultPerfCounter; external PdhDll
  name 'PdhGetDefaultPerfCounter';
function PdhBrowseCounters; external PdhDll name 'PdhBrowseCounters';
function PdhExpandCounterPath; external PdhDll name 'PdhExpandCounterPath';

{$ENDIF}

{ Functions }

function IsSuccessSeverity (ErrorCode : Integer) : Boolean;
begin
  Result:=(ErrorCode and $C0000000) = 0;
end;

function IsInformationalSeverity (ErrorCode : Integer) : Boolean;
begin
  Result:=(ErrorCode and $C0000000) = $40000000;
end;

function IsWarningSeverity (ErrorCode : Integer) : Boolean;
begin
  Result:=(ErrorCode and $C0000000) = $80000000;
end;

function IsErrorSeverity (ErrorCode : Integer) : Boolean;
begin
  Result:=(ErrorCode and $C0000000) = $C0000000;
end;

end.

